#ifndef __AVAPIS_SERVER_h__
#define __AVAPIS_SERVER_h__

#include <pthread.h>
#include <stdbool.h>

#include "P2PCam/AVFRAMEINFO.h"
#include "P2PCam/AVIOCTRLDEFs.h"
#include "IOTCDevice.h"
#include "AVServer.h"


#define MAX_CLIENT_NUMBER	128
#define MAX_UID_LENGTH 20
#define VIDEO_BUF_SIZE	(1024 * 300)
#define AUDIO_BUF_SIZE	1024

#define ENABLE_DTLS 0        // enable/disable DTLS encryption of AV data
#define ENABLE_RESEND 1      // enable/disable reliable data transfer

#define ENABLE_EMULATOR 0    // enable/disable the emulator stream for sample use only
#define ENABLE_DASA 0        // enable/disable the function of DASA 
#define ENABLE_TOKEN_AUTH 0  // enable/disable the function relate to token auth

#define SERVTYPE_STREAM_SERVER 0

#define FPS 30   // Video FPS

#define AUDIO_FORMAT_PCM  // modify this define for test which audio format

#ifdef AUDIO_FORMAT_PCM
#define AUDIO_FRAME_SIZE 640
#define AUDIO_FPS 25
#define AUDIO_CODEC 0x8C

#elif defined (AUDIO_FORMAT_ADPCM)
#define AUDIO_FRAME_SIZE 160
#define AUDIO_FPS 25
#define AUDIO_CODEC 0x8B

#elif defined (AUDIO_FORMAT_SPEEX)
#define AUDIO_FRAME_SIZE 38
#define AUDIO_FPS 56
#define AUDIO_CODEC 0x8D

#elif defined (AUDIO_FORMAT_MP3)
#define AUDIO_FRAME_SIZE 380
#define AUDIO_FPS 32
#define AUDIO_CODEC 0x8E

#elif defined (AUDIO_FORMAT_SPEEX_ENC)
#define AUDIO_FRAME_SIZE 160
#define AUDIO_ENCODED_SIZE 160
#define AUDIO_FPS 56
#define AUDIO_CODEC 0x8D

#elif defined (AUDIO_FORMAT_G726_ENC)
#define AUDIO_FRAME_SIZE 320
#define AUDIO_ENCODED_SIZE 40
#define AUDIO_FPS 50
#define AUDIO_CODEC 0x8F

#elif defined (AUDIO_FORMAT_G726)
#define AUDIO_FRAME_SIZE 40
#define AUDIO_FPS 50
#define AUDIO_CODEC 0x8F
#endif

typedef struct _AV_Client
{
	int avIndex;
	unsigned char bEnableAudio;
	unsigned char bEnableVideo;
	unsigned char bEnableSpeaker;
	unsigned char bStopPlayBack;
	unsigned char bPausePlayBack;
    unsigned char bTwoWayStream;
	int speakerCh;
	int playBackCh;
    int waitKeyFrame;
	pthread_t speakerThreadId;
	SMsgAVIoctrlPlayRecord playRecord;
	pthread_rwlock_t sLock;
#if ENABLE_DASA
    int doCleanBuffer;
    int doCleanBufferDone;
#endif
}AV_Client;

#endif

